@@ -35,3 +35,10 @@ class DotDict(dict):
             else:
                 result[key] = value
         return result
+
+
+def none_to_empty_str(d):
+    for k, v in d.items():
+        if v is None:
+            d[k] = ""
+    return d
